@@ -238,6 +238,9 @@ class SettImaging(object):
 
         :return: success
         """
+        canSetCCDTemp = self.app.camera.data.get('CAN_SET_CCD_TEMPERATURE', False)
+        if not canSetCCDTemp:
+            return False
 
         msg = PyQt5.QtWidgets.QMessageBox
         actValue = self.app.camera.data.get('CCD_TEMPERATURE.CCD_TEMPERATURE_VALUE')
@@ -261,7 +264,6 @@ class SettImaging(object):
             return False
 
         self.app.camera.sendCoolerTemp(temperature=value)
-
         return True
 
     def setFilterNumber(self):
@@ -271,7 +273,6 @@ class SettImaging(object):
 
         :return: success
         """
-
         msg = PyQt5.QtWidgets.QMessageBox
         data = self.app.filter.data
 
@@ -369,6 +370,10 @@ class SettImaging(object):
         """
         :return:
         """
+        canGetCoolerPower = self.app.camera.data.get('CAN_GET_COOLER_POWER', False)
+        if not canGetCoolerPower:
+            return False
+
         self.app.camera.sendCoolerSwitch(coolerOn=True)
         return True
 
@@ -376,6 +381,10 @@ class SettImaging(object):
         """
         :return:
         """
+        canGetCoolerPower = self.app.camera.data.get('CAN_GET_COOLER_POWER', False)
+        if not canGetCoolerPower:
+            return False
+
         self.app.camera.sendCoolerSwitch(coolerOn=False)
         return True
 
